@@ -85,6 +85,15 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 namespace ScreenLocker
 {
 
+// disable DrKonqi as the crash dialog blocks the restart of the locker
+void disableDrKonqi()
+{
+    KCrash::setDrKonqiEnabled(false);
+}
+// run immediately, before Q_CORE_STARTUP functions
+// that would enable drkonqi
+Q_CONSTRUCTOR_FUNCTION(disableDrKonqi)
+
 class FocusOutEventFilter : public QAbstractNativeEventFilter
 {
 public:
@@ -172,9 +181,6 @@ void UnlockApp::initialize()
     m_resetRequestIgnoreTimer->setInterval(2000);
     connect(m_resetRequestIgnoreTimer, &QTimer::timeout, this, &UnlockApp::resetRequestIgnore);
 
-    // disable DrKonqi as the crash dialog blocks the restart of the locker
-    KCrash::setDrKonqiEnabled(false);
-
     KScreenSaverSettings::self()->load();
     KPackage::Package package = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("Plasma/LookAndFeel"));
     KConfigGroup cg(KSharedConfig::openConfig(QStringLiteral("kdeglobals")), "KDE");
@@ -311,7 +317,7 @@ void UnlockApp::desktopResized()
 
         view->setSource(m_mainQmlPath);
         // on error, load the fallback lockscreen to not lock the user out of the system
-        if (view->status() == QQmlComponent::Error) {
+        if (view->status() != QQmlComponent::Ready) {
             static const QUrl fallbackUrl(QUrl(QStringLiteral("qrc:/fallbacktheme/LockScreen.qml")));
 
             qWarning() << "Failed to load lockscreen QML, falling back to built-in locker";
